@@ -8,13 +8,11 @@ Module to find the CodeGuru profiles from tagging API
 
 import re
 
-from botocore.exceptions import ClientError
-
 from ecs_composex.codeguru_profiler.codeguru_profiler_params import (
     PROFILER_ARN,
     PROFILER_NAME,
 )
-from ecs_composex.common import LOG, keyisset
+from ecs_composex.common import LOG
 from ecs_composex.common.aws import (
     define_lookup_role_from_info,
     find_aws_resource_arn_from_tags_api,
