@@ -7,6 +7,9 @@ from copy import deepcopy
 from json import dumps
 from os import path
 
+import docker
+import requests
+import urllib3
 from compose_x_common.compose_x_common import keyisset, keypresent
 from troposphere import (
     AWS_NO_VALUE,
@@ -25,6 +28,7 @@ from troposphere.ecs import (
     ContainerDefinition,
     DockerVolumeConfiguration,
     EnvironmentFile,
+    EphemeralStorage,
     HealthCheck,
     KernelCapabilities,
     LinuxParameters,
@@ -113,7 +117,6 @@ class ComposeService(object):
         ("extra_hosts", list),
         ("healthcheck", dict),
         ("hostname", str),
-        ("labels", dict),
         ("labels", (dict, list)),
         ("logging", dict),
         ("links", list),
@@ -145,6 +148,8 @@ class ComposeService(object):
         ("x-network", dict),
         ("x-alarms", dict),
         ("x-ecr", dict),
+        ("x-prometheus", dict),
+        ("x-docker_opts", dict),
     ]
 
     ecs_plugin_aws_keys = [
@@ -160,7 +165,10 @@ class ComposeService(object):
     def __init__(self, name, definition, volumes=None, secrets=None):
         if not isinstance(definition, dict):
             raise TypeError(
-                "The definition of a service must be", dict, "got", type(definition)
+                "The definition of a service must be",
+                dict,
+                "got",
+                type(definition),
             )
         if not all(
             key in [title[0] for title in self.ecs_plugin_aws_keys + self.keys]
@@ -205,6 +213,7 @@ class ComposeService(object):
         self.secrets = []
         self.env_files = []
         self.tmpfses = []
+        self.ephemeral_storage = 0
         self.user = None
         self.group = None
         self.user_group = None
@@ -224,6 +233,7 @@ class ComposeService(object):
             else Ref(AWS_NO_VALUE)
         )
         self.image = self.definition["image"]
+        self.image_digest = None
         self.image_param = Parameter(
             f"{self.logical_name}ImageUrl", Default=self.image, Type="String"
         )
@@ -232,6 +242,7 @@ class ComposeService(object):
         self.mem_alloc = None
         self.mem_resa = None
         self.cpu_amount = None
+        self.compute_platform = "FARGATE"
         self.families = []
         self.my_family = None
         self.is_aws_sidecar = False
@@ -255,6 +266,42 @@ class ComposeService(object):
         self.set_networks()
         self.ecr_config = set_else_none("x-ecr", self.definition, None)
 
+    def retrieve_image_digest(self):
+        valid_media_types = [
+            "application/vnd.docker.distribution.manifest.v1+json",
+            "application/vnd.docker.distribution.manifest.v2+json",
+            "application/vnd.docker.distribution.manifest.v1+prettyjws",
+            "application/vnd.docker.distribution.manifest.list.v2+json",
+        ]
+        try:
+            dkr_client = docker.APIClient()
+            image_details = dkr_client.inspect_distribution(self.image)
+            if not keyisset("Descriptor", image_details):
+                raise KeyError(f"No information retrieved for {self.image}")
+            details = image_details["Descriptor"]
+            if (
+                keyisset("mediaType", details)
+                and details["mediaType"] not in valid_media_types
+            ):
+                raise ValueError(
+                    "The mediaType is not valid. Got",
+                    details["mediaType"],
+                    "Expected one of",
+                    valid_media_types,
+                )
+            if keyisset("digest", details):
+                self.image_digest = details["digest"]
+            else:
+                LOG.warning(
+                    "No digest found. This might be due to Registry API prior to V2"
+                )
+
+        except (docker.errors.APIError, docker.errors.DockerException) as error:
+            LOG.error(f"Failed to retrieve the image digest for {self.image}")
+            print(error)
+        except (FileNotFoundError, urllib3.exceptions, requests.exceptions):
+            LOG.error("Failed to connect to any docker engine.")
+
     def define_port_mappings(self):
         """
         Method to determine the list of port mappings to use for either AWS VPC deployments or else (bridge etc).
@@ -272,6 +319,22 @@ class ComposeService(object):
             ]
         return aws_vpc_mappings, ec2_mappings
 
+    def import_docker_labels(self):
+        """
+        Method to import the Docker labels if defined
+        """
+        labels = {}
+        if not keyisset("labels", self.definition):
+            return labels
+        else:
+            if isinstance(self.definition["labels"], dict):
+                return self.definition["labels"]
+            elif isinstance(self.definition["labels"], list):
+                for label in self.definition["labels"]:
+                    splits = label.split("=")
+                    labels.update({splits[0]: splits[1] if len(splits) == 2 else ""})
+        return labels
+
     def set_container_definition(self):
         """
         Function to define the container definition matching the service definition
@@ -304,6 +367,7 @@ class ComposeService(object):
                 Ref(AWS_NO_VALUE),
                 keyisset("Privileged", self.definition),
             ),
+            DockerLabels=self.import_docker_labels(),
             ReadonlyRootFilesystem=keyisset("read_only", self.definition),
             WorkingDirectory=Ref(AWS_NO_VALUE)
             if not keyisset("working_dir", self.definition)
@@ -359,7 +423,9 @@ class ComposeService(object):
                     "awslogs-endpoint", options_def, alt_value=Ref(AWS_NO_VALUE)
                 ),
                 "awslogs-datetime-format": set_else_none(
-                    "awslogs-datetime-format", options_def, alt_value=Ref(AWS_NO_VALUE)
+                    "awslogs-datetime-format",
+                    options_def,
+                    alt_value=Ref(AWS_NO_VALUE),
                 ),
                 "awslogs-multiline-pattern": set_else_none(
                     "awslogs-multiline-pattern",
@@ -382,7 +448,12 @@ class ComposeService(object):
             ):
                 options["awslogs-create-group"] = options_def[
                     "awslogs-create-group"
-                ] in ["yes", "true", "Yes", "True"]
+                ] in [
+                    "yes",
+                    "true",
+                    "Yes",
+                    "True",
+                ]
             self.logging = LogConfiguration(
                 LogDriver="awslogs",
                 Options=options,
@@ -911,6 +982,64 @@ class ComposeService(object):
             if deployment[labels][essential_key] in negative_values:
                 self.is_essential = False
 
+    def define_ephemeral_storage_condition(self, deployment):
+        """
+        Method to define the start condition success for the container
+
+        :param deployment:
+        :return:
+        """
+        storage_key = "ecs.ephemeral.storage"
+        labels = "labels"
+        if not keyisset(labels, deployment) or (
+            keyisset(labels, deployment)
+            and not keyisset(storage_key, deployment[labels])
+        ):
+            return
+        storage_value = deployment[labels][storage_key]
+        if isinstance(storage_value, (int, float)):
+            ephemeral_storage = int(storage_value)
+        elif isinstance(storage_value, str):
+            ephemeral_storage = int(set_memory_to_mb(storage_value) / 1024)
+        else:
+            raise TypeError(
+                f"The value for {storage_key} is of type",
+                type(storage_value),
+                "Expected one of",
+                [int, float, str],
+            )
+        if ephemeral_storage < 21:
+            LOG.warning(
+                f"{self.name} - {storage_key}={ephemeral_storage} is smaller than 20(GB). Ignoring."
+            )
+        elif ephemeral_storage > 200:
+            LOG.warning(
+                f"{self.name} - {storage_key}={ephemeral_storage} is bigger than 200(GB). Setting to 200"
+            )
+            self.ephemeral_storage = 200
+        else:
+            self.ephemeral_storage = int(ephemeral_storage)
+            LOG.info(f"{self.name} - {storage_key} set to {self.ephemeral_storage}")
+
+    def define_compute_platform(self, deployment):
+        """
+        Determines whether to use ECS with EC2 or Fargate
+
+        :param dict deployment:
+        """
+        compute_key = "ecs.compute.platform"
+        labels = "labels"
+        allowed_values = ["EC2", "FARGATE", "EXTERNAL"]
+        if keyisset(labels, deployment) and keyisset(compute_key, deployment[labels]):
+            if not deployment[labels][compute_key] in allowed_values:
+                raise ValueError(
+                    f"ecs.compute.platform is {deployment[labels][compute_key]}"
+                    "Must be one of",
+                    allowed_values,
+                )
+            self.compute_platform = deployment[labels][compute_key]
+            LOG.info(f"{self.name} set ecs.compute.platform to {self.compute_platform}")
+
     def define_start_condition(self, deployment):
         """
         Method to define the start condition success for the container
@@ -992,8 +1121,10 @@ class ComposeService(object):
         self.set_compute_resources(self.definition[deploy])
         self.set_replicas(self.definition[deploy])
         self.define_start_condition(self.definition[deploy])
+        self.define_compute_platform(self.definition[deploy])
         self.define_essential(self.definition[deploy])
         self.set_update_config(self.definition[deploy])
+        self.define_ephemeral_storage_condition(self.definition[deploy])
 
 
 def handle_same_task_services_dependencies(services_config):
@@ -1020,7 +1151,10 @@ def handle_same_task_services_dependencies(services_config):
                 if s_service[1].name in service[1].depends_on
             ]
             parents_dependency = [
-                {"ContainerName": p.name, "Condition": p.container_start_condition}
+                {
+                    "ContainerName": p.name,
+                    "Condition": p.container_start_condition,
+                }
                 for p in parents
             ]
             setattr(service[1].container_definition, "DependsOn", parents_dependency)
@@ -1178,6 +1312,8 @@ class ComposeFamily(object):
     Class to group services logically to create the final ECS Service
     """
 
+    default_compute_platform = "FARGATE"
+
     def __init__(self, services, family_name):
         self.services = services
         self.ordered_services = []
@@ -1197,10 +1333,13 @@ class ComposeFamily(object):
         self.task_definition = None
         self.service_definition = None
         self.service_config = None
+        self.task_ephemeral_storage = 0
         self.exec_role = None
         self.task_role = None
         self.scalable_target = None
         self.ecs_service = None
+        self.compute_platform = "FARGATE"
+        self.set_compute_platform()
         self.task_logging_options = {}
         self.stack_parameters = {}
         self.alarms = {}
@@ -1213,14 +1352,22 @@ class ComposeFamily(object):
 
     def add_service(self, service):
         self.services.append(service)
+        if self.task_definition and service.container_definition:
+            self.task_definition.ContainerDefinitions.append(
+                service.container_definition
+            )
+            self.set_secrets_access()
         self.set_xray()
+        self.set_task_ephemeral_storage()
         self.refresh()
 
     def refresh(self):
         self.sort_container_configs()
+        self.set_compute_platform()
         self.handle_iam()
         self.handle_logging()
         self.apply_services_params()
+        self.set_task_compute_parameter()
 
     def set_initial_services_dependencies(self):
         """
@@ -1234,7 +1381,50 @@ class ComposeFamily(object):
                     if service_depends_on not in self.services_depends_on:
                         self.services_depends_on.append(service_depends_on)
 
+    def set_task_ephemeral_storage(self):
+        """
+        If any service ephemeral storage is defined above, sets the ephemeral storage to the maximum of them.
+        """
+        max_storage = max([service.ephemeral_storage for service in self.services])
+        if max_storage >= 21:
+            self.task_ephemeral_storage = max_storage
+
+    def set_compute_platform(self):
+        """
+        Iterates over all services and if ecs.compute.platform
+        :return:
+        """
+        if self.compute_platform != self.default_compute_platform:
+            LOG.warning(
+                f"{self.name} - The compute platform is already overridden to {self.compute_platform}"
+            )
+            if self.stack:
+                self.stack.Parameters.update(
+                    {ecs_params.LAUNCH_TYPE: self.compute_platform}
+                )
+            for service in self.services:
+                setattr(service, "compute_platform", self.compute_platform)
+        elif not all(
+            service.compute_platform == self.compute_platform
+            for service in self.services
+        ):
+            for service in self.services:
+                if service.compute_platform != self.compute_platform:
+                    platform = service.compute_platform
+                    LOG.info(
+                        f"{self.name} - At least one service is defined not to be on FARGATE."
+                        f" Overriding to {platform}"
+                    )
+                    self.compute_platform = platform
+                    if self.stack:
+                        self.stack.Parameters.update(
+                            {ecs_params.LAUNCH_TYPE: self.compute_platform}
+                        )
+
     def set_xray(self):
+        """
+        Automatically adds the xray-daemon sidecar to the task definition.
+        """
         self.use_xray = any(
             [keyisset("use_xray", service.x_configs) for service in self.services]
         )
@@ -1712,11 +1902,18 @@ class ComposeFamily(object):
             Cpu=ecs_params.FARGATE_CPU,
             Memory=ecs_params.FARGATE_RAM,
             NetworkMode=NETWORK_MODE,
+            EphemeralStorage=If(
+                USE_FARGATE_CON_T,
+                EphemeralStorage(SizeInGiB=self.task_ephemeral_storage),
+                Ref(AWS_NO_VALUE),
+            )
+            if 0 < self.task_ephemeral_storage >= 21
+            else Ref(AWS_NO_VALUE),
             Family=Ref(ecs_params.SERVICE_NAME),
             TaskRoleArn=GetAtt(TASK_ROLE_T, "Arn"),
             ExecutionRoleArn=GetAtt(EXEC_ROLE_T, "Arn"),
             ContainerDefinitions=[s.container_definition for s in self.services],
-            RequiresCompatibilities=["EC2", "FARGATE"],
+            RequiresCompatibilities=["EC2", "FARGATE", "EXTERNAL"],
             Tags=Tags(
                 {
                     "Name": Ref(ecs_params.SERVICE_NAME),
@@ -1724,6 +1921,13 @@ class ComposeFamily(object):
                 }
             ),
         )
+        for service in self.services:
+            service.container_definition.DockerLabels.update(
+                {
+                    "container_name": service.container_name,
+                    "ecs_task_family": Ref(ecs_params.SERVICE_NAME),
+                }
+            )
 
     def apply_services_params(self):
         if not self.template:
@@ -1740,7 +1944,8 @@ class ComposeFamily(object):
             logging_def.Options.update(self.task_logging_options)
 
     def init_task_definition(self):
-        add_service_roles(self)
+        if self.template:
+            add_service_roles(self)
         self.set_task_compute_parameter()
         self.set_task_definition()
         self.refresh_container_logging_definition()
@@ -1757,7 +1962,8 @@ class ComposeFamily(object):
                 self.stack_parameters.update(
                     {
                         APP_SUBNETS.title: Join(
-                            ",", FindInMap("Network", network.subnet_name, "Ids")
+                            ",",
+                            FindInMap("Network", network.subnet_name, "Ids"),
                         )
                     }
                 )
@@ -1986,3 +2192,31 @@ class ComposeFamily(object):
                 "RollBack": rollback,
             }
         )
+
+    def handle_prometheus(self):
+        """
+        Reviews services config
+        :return:
+        """
+        from ecs_composex.ecs.ecs_prometheus import add_cw_agent_to_family
+
+        insights_options = {
+            "CollectForAppMesh": False,
+            "CollectForJavaJmx": False,
+            "CollectForNginx": False,
+            "EnableTasksDiscovery": False,
+            "EnableCWAgentDebug": False,
+            "AutoAddNginxPrometheusExporter": False,
+        }
+        for service in self.services:
+            if keyisset("x-prometheus", service.definition):
+                prometheus_config = service.definition["x-prometheus"]
+                if keyisset("ContainersInsights", prometheus_config):
+                    config = service.definition["x-prometheus"]["ContainersInsights"]
+                    for key in insights_options.keys():
+                        if keyisset(key, config):
+                            insights_options[key] = config[key]
+                    if keyisset("CustomRules", config):
+                        insights_options.update({"CustomRules": config["CustomRules"]})
+        if any(insights_options.values()):
+            add_cw_agent_to_family(self, **insights_options)
