@@ -17,6 +17,7 @@ import jsonschema
 import yaml
 from botocore.exceptions import ClientError
 from cfn_flip.yaml_dumper import LongCleanDumper
+from compose_x_common.aws import validate_iam_role_arn
 from compose_x_common.compose_x_common import keyisset
 from compose_x_render.compose_x_render import ComposeDefinition
 from importlib_resources import files as pkg_files
@@ -32,7 +33,7 @@ from ecs_composex.common.cfn_params import USE_FLEET_T
 from ecs_composex.common.compose_networks import ComposeNetwork
 from ecs_composex.common.compose_services import ComposeFamily, ComposeService
 from ecs_composex.common.compose_volumes import ComposeVolume
-from ecs_composex.iam import ROLE_ARN_ARG, validate_iam_role_arn
+from ecs_composex.iam import ROLE_ARN_ARG
 from ecs_composex.secrets.compose_secrets import ComposeSecret
 from ecs_composex.utils.init_ecs import set_ecs_settings
 from ecs_composex.utils.init_s3 import create_bucket
@@ -48,7 +49,6 @@ class ComposeXSettings(object):
 
     create_vpc_arg = "CreateVpc"
     create_ec2_arg = "AddComputeResources"
-    create_spotfleet_arg = USE_FLEET_T
 
     region_arg = "RegionName"
     zones_arg = "Zones"
@@ -110,7 +110,12 @@ class ComposeXSettings(object):
     all_commands = active_commands + validation_commands + neutral_commands
 
     def __init__(
-        self, content=None, profile_name=None, session=None, for_macro=False, **kwargs
+        self,
+        content=None,
+        profile_name=None,
+        session=None,
+        for_macro=False,
+        **kwargs,
     ):
         """
         Class to init the configuration
@@ -167,6 +172,7 @@ class ComposeXSettings(object):
         self.evaluate_private_namespace()
         self.name = kwargs[self.name_arg]
         self.ecs_cluster = None
+        self.ecs_cluster_platform_override = None
         self.ignore_ecr_findings = keyisset(self.ecr_arg, kwargs)
 
     def evaluate_private_namespace(self):
@@ -252,7 +258,8 @@ class ComposeXSettings(object):
             return
         for volume_name in self.compose_content[ComposeVolume.main_key]:
             volume = ComposeVolume(
-                volume_name, self.compose_content[ComposeVolume.main_key][volume_name]
+                volume_name,
+                self.compose_content[ComposeVolume.main_key][volume_name],
             )
             self.compose_content[ComposeVolume.main_key][volume_name] = volume
             self.volumes.append(volume)
