@@ -35,17 +35,17 @@ try:
     from ecs_composex.ecr.ecr_scans_eval import (
         define_service_image,
         interpolate_ecr_uri_tag_with_digest,
+        invalidate_image_from_ecr,
         scan_service_image,
     )
 
     SCANS_POSSIBLE = True
 except ImportError:
     warnings.warn(
-        "You must install ecs-composex[ECRScan] extra to use this functionality"
+        "You must install ecs-composex[ecrscan] extra to use this functionality"
     )
     SCANS_POSSIBLE = False
 
-
 RES_REGX = re.compile(r"(^([x-]+))")
 COMPUTE_STACK_NAME = "Ec2Compute"
 VPC_STACK_NAME = "vpc"
@@ -321,6 +321,35 @@ def init_root_template(settings):
     return template
 
 
+def evaluate_docker_configs(settings):
+    """
+    Function to go over the services settings and evaluate x-docker
+
+    :param ecs_composex.common.settings.ComposeXSettings settings: The settings for the execution
+    :return:
+    """
+    image_tag_re = re.compile(r"(?P<tag>(?:\@sha[\d]+:[a-z-Z0-9]+$)|(?::[\S]+$))")
+    for family in settings.families.values():
+        for service in family.services:
+            if not keyisset("x-docker_opts", service.definition):
+                continue
+            docker_config = service.definition["x-docker_opts"]
+            if keyisset("InterpolateWithDigest", docker_config):
+                if not invalidate_image_from_ecr(service, mute=True):
+                    LOG.warn(
+                        "You set InterpolateWithDigest to true for x-docker for an image in AWS ECR."
+                        "Please refer to x-ecr"
+                    )
+                    continue
+                service.retrieve_image_digest()
+                if service.image_digest:
+                    service.image = image_tag_re.sub(
+                        f"@{service.image_digest}", service.image
+                    )
+                    LOG.info(f"Successfully retrieved digest for {service.name}.")
+                    LOG.info(f"{service.name} - {service.image}")
+
+
 def evaluate_ecr_configs(settings):
     """
     Function to go over each service of each family in its final state and evaluate the ECR Image validity.
@@ -333,6 +362,10 @@ def evaluate_ecr_configs(settings):
         return result
     for family in settings.families.values():
         for service in family.services:
+            if not keyisset("x-ecr", service.definition) or invalidate_image_from_ecr(
+                service, True
+            ):
+                continue
             service_image = define_service_image(service, settings)
             if (
                 service.ecr_config
@@ -348,6 +381,8 @@ def evaluate_ecr_configs(settings):
             if scan_service_image(service, settings, service_image):
                 LOG.warn(f"{family.name}.{service.name} - vulnerabilities found")
                 result = 1
+            else:
+                LOG.info(f"{family.name}.{service.name} - ECR Evaluation Passed.")
     return result
 
 
@@ -360,6 +395,7 @@ def generate_full_template(settings):
     :rtype: root_template, list
     """
     LOG.debug(settings)
+    evaluate_docker_configs(settings)
     root_stack_title = NONALPHANUM.sub("", settings.name.title())
     root_stack = ComposeXStack(
         root_stack_title,
@@ -386,7 +422,10 @@ def generate_full_template(settings):
     apply_x_to_x_configs(root_stack, settings)
     if settings.use_appmesh:
         mesh = Mesh(
-            settings.compose_content["x-appmesh"], root_stack, settings, dns_settings
+            settings.compose_content["x-appmesh"],
+            root_stack,
+            settings,
+            dns_settings,
         )
         mesh.render_mesh_template(root_stack, settings, dns_settings)
     dns_records = DnsRecords(settings)
@@ -394,6 +433,6 @@ def generate_full_template(settings):
     dns_settings.associate_settings_to_nested_stacks(root_stack)
     set_services_alarms(settings)
     if keyisset("x-dashboards", settings.compose_content):
-        dashboards_stack = DashboardsStack("dashboards", settings)
+        DashboardsStack("dashboards", settings)
     add_all_tags(root_stack.stack_template, settings)
     return root_stack
