@@ -14,7 +14,10 @@ S3_ARN_REGEX = r"arn:(aws|aws-gov|aws-cn):s3:::([a-zA-Z0-9-.]+$)"
 
 S3_BUCKET_ARN_T = "BucketArn"
 S3_BUCKET_ARN = Parameter(
-    S3_BUCKET_ARN_T, return_value="Arn", Type="String", AllowedPattern=S3_ARN_REGEX
+    S3_BUCKET_ARN_T,
+    return_value="Arn",
+    Type="String",
+    AllowedPattern=S3_ARN_REGEX,
 )
 S3_BUCKET_NAME_T = "BucketName"
 S3_BUCKET_NAME = Parameter(
@@ -27,5 +30,7 @@ S3_BUCKET_DOMAIN_NAME = Parameter(
 
 S3_BUCKET_REGION_DOMAIN_NAME_T = "BucketDomainName"
 S3_BUCKET_REGION_DOMAIN_NAME = Parameter(
-    S3_BUCKET_REGION_DOMAIN_NAME_T, return_value="RegionalDomainName", Type="String"
+    S3_BUCKET_REGION_DOMAIN_NAME_T,
+    return_value="RegionalDomainName",
+    Type="String",
 )
